@@ -144,7 +144,7 @@ pal_point_trend2 <- c("#4575B4", "#D73027")
 #' @export
 #' @examples
 #' scales::show_col(pal_point_trend3)
-pal_point_trend3 <- c("#4575B4", "#D3D3D3", "#D73027")
+pal_point_trend3 <- c("#4575B4", "#BDBDBD", "#D73027")
 
 #' @title Colour palette for a categorical trend variable with 5 values for points.
 #' @description Colour palette for categorical variables.
@@ -152,7 +152,7 @@ pal_point_trend3 <- c("#4575B4", "#D3D3D3", "#D73027")
 #' @export
 #' @examples
 #' scales::show_col(pal_point_trend5)
-pal_point_trend5 <- c("#4575B4", "#90C3DD", "#D3D3D3", "#F98E52", "#D73027")
+pal_point_trend5 <- c("#4575B4", "#90C3DD", "#BDBDBD", "#F98E52", "#D73027")
 
 #' @title Signed square root ggplot scale transformation.
 #' @description A signed square root ggplot scale transformation.
