@@ -119,7 +119,7 @@ ggplot_sf <- function(data,
                       coastline = NULL,
                       title = "[Title]",
                       subtitle = NULL,
-                      caption = "",
+                      caption = NULL,
                       font_family = "Helvetica",
                       font_size_title = NULL,
                       font_size_body = NULL,
@@ -265,7 +265,7 @@ ggplot_sf_col <- function(data,
                           title = "[Title]",
                           subtitle = NULL,
                           col_title = "",
-                          caption = "",
+                          caption = NULL,
                           legend_labels = NULL,
                           font_family = "Helvetica",
                           font_size_title = NULL,
@@ -482,7 +482,7 @@ ggplot_sf_facet <- function(data,
                             coastline_pal = "#7f7f7f",
                             title = "[Title]",
                             subtitle = NULL,
-                            caption = "",
+                            caption = NULL,
                             font_family = "Helvetica",
                             font_size_title = NULL,
                             font_size_body = NULL,
@@ -657,7 +657,7 @@ ggplot_sf_col_facet <- function(data,
                                 title = "[Title]",
                                 subtitle = NULL,
                                 col_title = "",
-                                caption = "",
+                                caption = NULL,
                                 legend_labels = NULL,
                                 font_family = "Helvetica",
                                 font_size_title = NULL,
